summaryrefslogtreecommitdiffstats
path: root/ktouch/src/ktouchstatus.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:30:46 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:30:46 -0600
commit999f961ff5278b84c8ffd8a91addb9343e589cf0 (patch)
treeed392c698357e3037e6d9f5f40a33797b72e6129 /ktouch/src/ktouchstatus.h
parent2d7b541a4e0095d40e37aaefbf9c4a9b9d149302 (diff)
downloadtdeedu-999f961ff5278b84c8ffd8a91addb9343e589cf0.tar.gz
tdeedu-999f961ff5278b84c8ffd8a91addb9343e589cf0.zip
Rename old tq methods that no longer need a unique name
Diffstat (limited to 'ktouch/src/ktouchstatus.h')
-rw-r--r--ktouch/src/ktouchstatus.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/ktouch/src/ktouchstatus.h b/ktouch/src/ktouchstatus.h
index 229ed903..f4be66f4 100644
--- a/ktouch/src/ktouchstatus.h
+++ b/ktouch/src/ktouchstatus.h
@@ -22,21 +22,21 @@
/** This is the implementation of the status widget (at the top of the main view).
* It simply displays the status but does not have a functionality of its own.
* Everythings is calculated in the trainer (see KTouchTrainer)and then displayed
* using the updatetqStatus() member function.
* The "new characters" string is set using the member function setNewChars().
*/
-class KTouchtqStatus : public KTouchStatusLayout {
+class KTouchStatus : public KTouchStatusLayout {
Q_OBJECT
TQ_OBJECT
public:
/// Constructor
- KTouchtqStatus(TQWidget *parent);
+ KTouchStatus(TQWidget *parent);
/// Called when the preferences have changed in the configuration dialog.
void applyPreferences();
/// Sets the new characters text.
void setNewChars(const TQString& newChars);
/// Updates the level LCD and the correctness progress bar
- void updatetqStatus(unsigned int level, double correctness);
+ void updateStatus(unsigned int level, double correctness);
};
#endif // KTOUCHSTATUS_H
@@ -22,21 +22,21 @@
* It simply displays the status but does not have a functionality of its own.
* Everythings is calculated in the trainer (see KTouchTrainer)and then displayed
- * using the updatetqStatus() member function.
+ * using the updateStatus() member function.
* The "new characters" string is set using the member function setNewChars().
*/